@@ -9,7 +9,8 @@
 //  Module:         Application configuration data
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
+// Guy Voncken
 //
 // This file is part of Guymager.
 //
@@ -407,6 +408,7 @@ static t_ToolCfgParamDesc CfgParamDescArr[] =
    {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"ScreenRefreshInterval"         , CFGTYPE_INTEGER, ELT(ScreenRefreshInterval         ),                0,       1, 8640000, NULL                            }, CFG_FILLUP_FORLINT},
    {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"UseFileDialogFromQt"           , CFGTYPE_SET    , ELT(UseFileDialogFromQt)           ,                0,       0,       0, INIARR(SetArrBoolean)           }, CFG_FILLUP_FORLINT},
    {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"UserFieldName"                 , CFGTYPE_STRING , ELT_SIZ(UserFieldName             ),                         0,       0, NULL                            }, CFG_FILLUP_FORLINT},
+   {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"AdditionalStateInfoName"       , CFGTYPE_STRING , ELT_SIZ(AdditionalStateInfoName   ),                         0,       0, NULL                            }, CFG_FILLUP_FORLINT},
 
    {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"WarnAboutImageSize"            , CFGTYPE_SET    , ELT(WarnAboutImageSize)            ,                0,       0,       0, INIARR(SetArrBoolean)           }, CFG_FILLUP_FORLINT},
    {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"WarnAboutSegmentFileCount"     , CFGTYPE_SET    , ELT(WarnAboutSegmentFileCount)     ,                0,       0,       0, INIARR(SetArrBoolean)           }, CFG_FILLUP_FORLINT},
@@ -452,6 +454,8 @@ static t_ToolCfgParamDesc CfgParamDescArr[] =
    {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"FifoMemoryManager"             , CFGTYPE_SET    , ELT(FifoMemoryManager)             ,                0,       0,       0, INIARR(SetArrBoolean)           }, CFG_FILLUP_FORLINT},
    {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"UseSeparateHashThread"         , CFGTYPE_SET    , ELT(UseSeparateHashThread)         ,                0,       0,       0, INIARR(SetArrBoolean)           }, CFG_FILLUP_FORLINT},
    {CFGASSIGN_BOTH_MULTIPLE, CfgIniCPUs , {"CompressionThreads"            , CFGTYPE_SET    , ELT(CompressionThreads)            ,                0,       0,    1024, INIARR(SetArrCompressionThreads)}, CFG_FILLUP_FORLINT},
+   {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"BadSectorLogThreshold"         , CFGTYPE_INTEGER, ELT(BadSectorLogThreshold)         ,                0,       0,99999999, NULL                            }, CFG_FILLUP_FORLINT},
+   {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"BadSectorLogModulo"            , CFGTYPE_INTEGER, ELT(BadSectorLogModulo)            ,                0,       1,99999999, NULL                            }, CFG_FILLUP_FORLINT},
    {CFGASSIGN_BOTH_MULTIPLE, CfgIniJobs , {"LimitJobs"                     , CFGTYPE_SET    , ELT(LimitJobs)                     ,                0,       1,       8, INIARR(SetArrMaximumJobs)       }, CFG_FILLUP_FORLINT},
    {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"JobMaxBadSectors"              , CFGTYPE_INTEGER, ELT(JobMaxBadSectors)              ,                0,       0,99999999, NULL                            }, CFG_FILLUP_FORLINT},
    {CFGASSIGN_BOTH_MULTIPLE, NULL       , {"JobDisconnectTimeout"          , CFGTYPE_INTEGER, ELT(JobDisconnectTimeout)          ,                0,       0,99999999, NULL                            }, CFG_FILLUP_FORLINT},
