@@ -9,7 +9,8 @@
 //  Module:         Application configuration data
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
+// Guy Voncken
 //
 // This file is part of Guymager.
 //
@@ -147,7 +148,8 @@ typedef struct
    t_CfgNumberStyle     NumberStyle;
    int                  ScreenRefreshInterval;
    int                  UseFileDialogFromQt;
-   char                 UserFieldName[CFG_MAX_MISC_LEN+1];
+   char                 UserFieldName          [CFG_MAX_MISC_LEN+1];
+   char                 AdditionalStateInfoName[CFG_MAX_MISC_LEN+1];
 
    int                  WarnAboutImageSize;
    int                  WarnAboutSegmentFileCount;
@@ -194,6 +196,8 @@ typedef struct
    int                  FifoMemoryManager;
    int                  UseSeparateHashThread;
    int                  CompressionThreads;
+   int                  BadSectorLogThreshold;
+   int                  BadSectorLogModulo;
    int                  LimitJobs;
    int                  JobMaxBadSectors;
    int                  JobDisconnectTimeout;
