@@ -11,7 +11,8 @@
 //                  window.
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
+// Guy Voncken
 //
 // This file is part of Guymager.
 //
@@ -888,6 +889,8 @@ void t_Device::ProcessTokenString (QString &Str, t_pDevice pDevice)
       DeviceReplace (Str, "%BadSectors%"     , GetBadSectorCount (pDevice).toString());
       DeviceReplace (Str, "%HiddenAreas%"    , GetHiddenAreas    (pDevice).toString());
       DeviceReplace (Str, "%ExtendedState%"  , GetState          (pDevice).toString());
+      DeviceReplace (Str, "%UserField%"      , GetUserField      (pDevice).toString());
+      DeviceReplace (Str, "%AddStateInfo%"   , GetAddStateInfo   (pDevice).toString());
    }
 
    DeviceReplace (Str, "%Version%" , QString(pCompileInfoVersion));
