@@ -4,13 +4,13 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="main.cpp" line="+509"/>
+        <location filename="main.cpp" line="+580"/>
         <source>Guymager needs to be started with root rights in order to perform acquisitions. You are not root and thus won&apos;t be able to acquire devices.
 Continue anyway?</source>
         <translation type="unfinished">GUYMAGER需要以管理员的身份运行，你目前不是管理员权限，确定继续吗？</translation>
     </message>
     <message>
-        <location filename="threadwrite.cpp" line="+1480"/>
+        <location filename="threadwrite.cpp" line="+1482"/>
         <source>Deleting %1</source>
         <translation type="unfinished">删除 %1</translation>
     </message>
@@ -21,9 +21,9 @@ Continue anyway?</source>
         <translation type="unfinished">非管理员权限</translation>
     </message>
     <message>
-        <location filename="dlgabort.cpp" line="+83"/>
-        <location filename="dlgacquire.cpp" line="+811"/>
-        <location filename="dlgdirsel.cpp" line="+106"/>
+        <location filename="dlgabort.cpp" line="+84"/>
+        <location filename="dlgacquire.cpp" line="+812"/>
+        <location filename="dlgdirsel.cpp" line="+107"/>
         <source>Ok</source>
         <translation type="unfinished">确定</translation>
     </message>
@@ -36,7 +36,7 @@ Continue anyway?</source>
         <translation type="unfinished">取消</translation>
     </message>
     <message>
-        <location filename="file.cpp" line="+67"/>
+        <location filename="file.cpp" line="+68"/>
         <source>Linux dd raw image</source>
         <translation type="unfinished"></translation>
     </message>
@@ -51,7 +51,7 @@ Continue anyway?</source>
         <translation type="unfinished">A高级司法镜像</translation>
     </message>
     <message>
-        <location filename="threadscan.cpp" line="+1440"/>
+        <location filename="threadscan.cpp" line="+1441"/>
         <source>Guymager cannot scan the devices connected to this computer.</source>
         <translation type="unfinished">GUYMAGER 无法扫描到设备</translation>
     </message>
@@ -148,7 +148,7 @@ remaining</source>
         <translation type="obsolete">剩余时间</translation>
     </message>
     <message>
-        <location filename="mainwindow.h" line="+49"/>
+        <location filename="mainwindow.h" line="+50"/>
         <source>Model</source>
         <translation type="unfinished">设备名</translation>
     </message>
@@ -304,8 +304,8 @@ Do you accept these changes?</source>
 是否同意此项变化</translation>
     </message>
     <message>
-        <location filename="config.h" line="+274"/>
-        <location filename="table.cpp" line="+345"/>
+        <location filename="config.h" line="+278"/>
+        <location filename="table.cpp" line="+346"/>
         <source>EwfCaseNumber</source>
         <translation type="unfinished">案件序列号</translation>
     </message>
@@ -679,7 +679,7 @@ Do you want to continue anyway?</source>
 <context>
     <name>t_DlgAutoExit</name>
     <message>
-        <location filename="dlgautoexit.cpp" line="+85"/>
+        <location filename="dlgautoexit.cpp" line="+86"/>
         <source>Abort</source>
         <translation type="unfinished">终止</translation>
     </message>
@@ -724,7 +724,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_DlgMessage</name>
     <message>
-        <location filename="dlgmessage.cpp" line="+100"/>
+        <location filename="dlgmessage.cpp" line="+101"/>
         <source>Close</source>
         <translation type="unfinished">关闭</translation>
     </message>
@@ -732,14 +732,18 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_Info</name>
     <message>
-        <location filename="info.cpp" line="+201"/>
+        <location filename="info.cpp" line="+202"/>
         <source>Command executed: %1</source>
         <translation type="unfinished">执行命令：%1</translation>
     </message>
     <message>
         <location line="+5"/>
+        <source>No information can be displayed as a timeout occurred while executing the command.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>No information can be displayed as a timeout occured while executing the command.</source>
-        <translation type="unfinished">无信息，命令执行超时</translation>
+        <translation type="obsolete">无信息，命令执行超时</translation>
     </message>
     <message>
         <location line="+7"/>
@@ -750,7 +754,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_InfoField</name>
     <message>
-        <location filename="infofield.cpp" line="+109"/>
+        <location filename="infofield.cpp" line="+110"/>
         <source>Size</source>
         <translation type="unfinished">大小</translation>
     </message>
@@ -866,7 +870,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_MainWindow</name>
     <message>
-        <location filename="device.cpp" line="+398"/>
+        <location filename="device.cpp" line="+399"/>
         <source>Local device</source>
         <translation type="unfinished">本地设备</translation>
     </message>
@@ -903,7 +907,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="obsolete">中止 - 硬盘读取错误</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="+291"/>
+        <location filename="mainwindow.cpp" line="+292"/>
         <source>&amp;Rescan</source>
         <translation type="unfinished">&amp;R重新扫描</translation>
     </message>
@@ -913,13 +917,13 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+195"/>
+        <location line="+201"/>
         <source>Device already contained</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+154"/>
+        <location line="+160"/>
         <source>There are active acquisitions. Do you really want to abort them and quit?</source>
         <translation type="unfinished">There are active acquisitions. 你确定放弃并退出？</translation>
     </message>
@@ -959,7 +963,7 @@ Using libguytools %5</source>
         <translation type="unfinished">退出</translation>
     </message>
     <message>
-        <location line="-344"/>
+        <location line="-356"/>
         <source>&amp;Devices</source>
         <translation type="unfinished">&amp;D设备</translation>
     </message>
@@ -1053,7 +1057,7 @@ Using libguytools %5</source>
         <translation type="unfinished">添加特殊设备</translation>
     </message>
     <message>
-        <location line="+155"/>
+        <location line="+161"/>
         <source>Open File</source>
         <translation type="unfinished">打开文件</translation>
     </message>
@@ -1112,12 +1116,12 @@ Using libguytools %5</source>
         <translation type="unfinished">未知</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-173"/>
+        <location filename="mainwindow.cpp" line="-179"/>
         <source>Exit after acquisitions completed</source>
         <translation type="unfinished">在获取完成后退出</translation>
     </message>
     <message>
-        <location line="+405"/>
+        <location line="+417"/>
         <source>(not used as Guymager currently is configured to use its own EWF module)</source>
         <translation type="unfinished"></translation>
     </message>
