@@ -4,7 +4,7 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="main.cpp" line="+508"/>
+        <location filename="main.cpp" line="+579"/>
         <source>Missing root rights</source>
         <comment>Dialog title</comment>
         <translation>Keine Root-Rechte</translation>
@@ -17,14 +17,14 @@ Continue anyway?</source>
 Trotzdem fortfahren?</translation>
     </message>
     <message>
-        <location filename="threadwrite.cpp" line="+1480"/>
+        <location filename="threadwrite.cpp" line="+1482"/>
         <source>Deleting %1</source>
         <translation>Lösche %1</translation>
     </message>
     <message>
-        <location filename="dlgabort.cpp" line="+83"/>
-        <location filename="dlgacquire.cpp" line="+811"/>
-        <location filename="dlgdirsel.cpp" line="+106"/>
+        <location filename="dlgabort.cpp" line="+84"/>
+        <location filename="dlgacquire.cpp" line="+812"/>
+        <location filename="dlgdirsel.cpp" line="+107"/>
         <source>Ok</source>
         <translation>Ok</translation>
     </message>
@@ -37,7 +37,7 @@ Trotzdem fortfahren?</translation>
         <translation>Abbruch</translation>
     </message>
     <message>
-        <location filename="file.cpp" line="+67"/>
+        <location filename="file.cpp" line="+68"/>
         <source>Linux dd raw image</source>
         <translation>Linux dd-Image</translation>
     </message>
@@ -52,7 +52,7 @@ Trotzdem fortfahren?</translation>
         <translation>AFF-Format</translation>
     </message>
     <message>
-        <location filename="threadscan.cpp" line="+1440"/>
+        <location filename="threadscan.cpp" line="+1441"/>
         <source>Guymager cannot scan the devices connected to this computer.</source>
         <translation>Guymager kann die angeschlossenen Geräte nicht abfragen.</translation>
     </message>
@@ -167,7 +167,7 @@ Belegung
 [%]</translation>
     </message>
     <message>
-        <location filename="mainwindow.h" line="+47"/>
+        <location filename="mainwindow.h" line="+48"/>
         <source>SerialNr</source>
         <translation>Serien-
 nummer</translation>
@@ -316,8 +316,8 @@ Geschwindigkeit
 <context>
     <name>t_DlgAcquire</name>
     <message>
-        <location filename="config.h" line="+274"/>
-        <location filename="table.cpp" line="+345"/>
+        <location filename="config.h" line="+278"/>
+        <location filename="table.cpp" line="+346"/>
         <source>EwfCaseNumber</source>
         <translation>Fallnummer</translation>
     </message>
@@ -740,7 +740,7 @@ Möchten Sie trotzdem fortfahren?</translation>
 <context>
     <name>t_DlgAutoExit</name>
     <message>
-        <location filename="dlgautoexit.cpp" line="+85"/>
+        <location filename="dlgautoexit.cpp" line="+86"/>
         <source>Abort</source>
         <translation>Abbruch</translation>
     </message>
@@ -785,7 +785,7 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
 <context>
     <name>t_DlgMessage</name>
     <message>
-        <location filename="dlgmessage.cpp" line="+100"/>
+        <location filename="dlgmessage.cpp" line="+101"/>
         <source>Close</source>
         <translation>Schließen</translation>
     </message>
@@ -793,15 +793,19 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
 <context>
     <name>t_Info</name>
     <message>
-        <location filename="info.cpp" line="+201"/>
+        <location filename="info.cpp" line="+202"/>
         <source>Command executed: %1</source>
         <translation>Ausgeführter Befehl: %1</translation>
     </message>
     <message>
         <location line="+5"/>
-        <source>No information can be displayed as a timeout occured while executing the command.</source>
+        <source>No information can be displayed as a timeout occurred while executing the command.</source>
         <translation>Der Befehl benötigte zu lange; keine Informationen vorhanden.</translation>
     </message>
+    <message>
+        <source>No information can be displayed as a timeout occured while executing the command.</source>
+        <translation type="vanished">Der Befehl benötigte zu lange; keine Informationen vorhanden.</translation>
+    </message>
     <message>
         <location line="+7"/>
         <source>Information returned:</source>
@@ -811,7 +815,7 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
 <context>
     <name>t_InfoField</name>
     <message>
-        <location filename="infofield.cpp" line="+109"/>
+        <location filename="infofield.cpp" line="+110"/>
         <source>Size</source>
         <translation>Größe</translation>
     </message>
@@ -927,7 +931,7 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
 <context>
     <name>t_MainWindow</name>
     <message>
-        <location filename="device.cpp" line="+398"/>
+        <location filename="device.cpp" line="+399"/>
         <source>Local device</source>
         <translation>Lokales Gerät</translation>
     </message>
@@ -964,7 +968,7 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
         <translation type="obsolete">Abbruch - Lesefehler</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="+291"/>
+        <location filename="mainwindow.cpp" line="+292"/>
         <source>&amp;Rescan</source>
         <translation>&amp;Auffrischen</translation>
     </message>
@@ -974,13 +978,13 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
         <translation>F5</translation>
     </message>
     <message>
-        <location line="+195"/>
+        <location line="+201"/>
         <source>Device already contained</source>
         <comment>Dialog title</comment>
         <translation>Gerät bereits vorhanden</translation>
     </message>
     <message>
-        <location line="+154"/>
+        <location line="+160"/>
         <source>There are active acquisitions. Do you really want to abort them and quit?</source>
         <translation>GUYMAGER hat noch Akquisitionen laufen. Möchten Sie diese abbrechen und das Programm verlassen?</translation>
     </message>
@@ -1024,7 +1028,7 @@ Benutzt libguytools %5</translation>
         <translation>GUYMAGER verlassen</translation>
     </message>
     <message>
-        <location line="-344"/>
+        <location line="-356"/>
         <source>&amp;Devices</source>
         <translation>&amp;Geräte</translation>
     </message>
@@ -1118,7 +1122,7 @@ Benutzt libguytools %5</translation>
         <translation>Sondergerät hinzufügen</translation>
     </message>
     <message>
-        <location line="+155"/>
+        <location line="+161"/>
         <source>Open File</source>
         <translation>Datei öffnen</translation>
     </message>
@@ -1177,7 +1181,7 @@ Benutzt libguytools %5</translation>
         <translation>nicht feststellbar</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-173"/>
+        <location filename="mainwindow.cpp" line="-179"/>
         <source>Exit after acquisitions completed</source>
         <translation>Guymager nach Abschluss aller Akquisitionen beenden</translation>
     </message>
@@ -1190,7 +1194,7 @@ Benutzt libguytools %5</translation>
         <translation type="obsolete">Abbruch - Startfehler Akquisition</translation>
     </message>
     <message>
-        <location line="+405"/>
+        <location line="+417"/>
         <source>(not used as Guymager currently is configured to use its own EWF module)</source>
         <translation>(inaktiv, da das Guymager-interne EWF-Modul konfiguriert ist)</translation>
     </message>
