@@ -4,9 +4,9 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="dlgabort.cpp" line="+83"/>
-        <location filename="dlgacquire.cpp" line="+811"/>
-        <location filename="dlgdirsel.cpp" line="+106"/>
+        <location filename="dlgabort.cpp" line="+84"/>
+        <location filename="dlgacquire.cpp" line="+812"/>
+        <location filename="dlgdirsel.cpp" line="+107"/>
         <source>Ok</source>
         <translation>Ok</translation>
     </message>
@@ -19,7 +19,7 @@
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="file.cpp" line="+67"/>
+        <location filename="file.cpp" line="+68"/>
         <source>Linux dd raw image</source>
         <translation>Image brute Linux dd</translation>
     </message>
@@ -29,7 +29,7 @@
         <translation>Format EWF, sous-format %1 </translation>
     </message>
     <message>
-        <location filename="main.cpp" line="+508"/>
+        <location filename="main.cpp" line="+579"/>
         <source>Missing root rights</source>
         <comment>Dialog title</comment>
         <translation>Droits «root»</translation>
@@ -42,7 +42,7 @@ Continue anyway?</source>
 Continuer quand-même?</translation>
     </message>
     <message>
-        <location filename="threadwrite.cpp" line="+1480"/>
+        <location filename="threadwrite.cpp" line="+1482"/>
         <source>Deleting %1</source>
         <translation>Efface %1</translation>
     </message>
@@ -52,7 +52,7 @@ Continuer quand-même?</translation>
         <translation>Format AFF</translation>
     </message>
     <message>
-        <location filename="threadscan.cpp" line="+1440"/>
+        <location filename="threadscan.cpp" line="+1441"/>
         <source>Guymager cannot scan the devices connected to this computer.</source>
         <translation>Guymager ne peut déterminer les médias connectés.</translation>
     </message>
@@ -169,7 +169,7 @@ des FIFOs
 [%]</translation>
     </message>
     <message>
-        <location filename="mainwindow.h" line="+47"/>
+        <location filename="mainwindow.h" line="+48"/>
         <source>SerialNr</source>
         <translation>Nº de
 série</translation>
@@ -320,8 +320,8 @@ actuelle
 <context>
     <name>t_DlgAcquire</name>
     <message>
-        <location filename="config.h" line="+274"/>
-        <location filename="table.cpp" line="+345"/>
+        <location filename="config.h" line="+278"/>
+        <location filename="table.cpp" line="+346"/>
         <source>EwfCaseNumber</source>
         <translation>Numéro d&apos;affaire</translation>
     </message>
@@ -745,7 +745,7 @@ Voulez vous toujours continuer?</translation>
 <context>
     <name>t_DlgAutoExit</name>
     <message>
-        <location filename="dlgautoexit.cpp" line="+85"/>
+        <location filename="dlgautoexit.cpp" line="+86"/>
         <source>Abort</source>
         <translation>Annuler</translation>
     </message>
@@ -790,7 +790,7 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
 <context>
     <name>t_DlgMessage</name>
     <message>
-        <location filename="dlgmessage.cpp" line="+100"/>
+        <location filename="dlgmessage.cpp" line="+101"/>
         <source>Close</source>
         <translation>Fermer</translation>
     </message>
@@ -798,15 +798,19 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
 <context>
     <name>t_Info</name>
     <message>
-        <location filename="info.cpp" line="+201"/>
+        <location filename="info.cpp" line="+202"/>
         <source>Command executed: %1</source>
         <translation>Commande  exécutée: %1</translation>
     </message>
     <message>
         <location line="+5"/>
-        <source>No information can be displayed as a timeout occured while executing the command.</source>
+        <source>No information can be displayed as a timeout occurred while executing the command.</source>
         <translation>Aucune information n&apos;est disponible suite au dépassement du temps d&apos;exécution maximal.</translation>
     </message>
+    <message>
+        <source>No information can be displayed as a timeout occured while executing the command.</source>
+        <translation type="vanished">Aucune information n&apos;est disponible suite au dépassement du temps d&apos;exécution maximal.</translation>
+    </message>
     <message>
         <location line="+7"/>
         <source>Information returned:</source>
@@ -816,7 +820,7 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
 <context>
     <name>t_InfoField</name>
     <message>
-        <location filename="infofield.cpp" line="+109"/>
+        <location filename="infofield.cpp" line="+110"/>
         <source>Size</source>
         <translation>Capacité</translation>
     </message>
@@ -932,7 +936,7 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
 <context>
     <name>t_MainWindow</name>
     <message>
-        <location filename="device.cpp" line="+398"/>
+        <location filename="device.cpp" line="+399"/>
         <source>Local device</source>
         <translation>Média local</translation>
     </message>
@@ -969,7 +973,7 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
         <translation type="obsolete">Abandon - erreur grave de lecture </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="+291"/>
+        <location filename="mainwindow.cpp" line="+292"/>
         <source>&amp;Rescan</source>
         <translation>&amp;Actualiser</translation>
     </message>
@@ -1014,13 +1018,13 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
         <translation>A propos de &amp;Qt</translation>
     </message>
     <message>
-        <location line="+175"/>
+        <location line="+181"/>
         <source>Device already contained</source>
         <comment>Dialog title</comment>
         <translation>Média déjà existant</translation>
     </message>
     <message>
-        <location line="+154"/>
+        <location line="+160"/>
         <source>Exit GUYMAGER</source>
         <comment>Dialog title</comment>
         <translation>Quitter GUYMAGER</translation>
@@ -1112,7 +1116,7 @@ Utilise libguytools %5</translation>
         <translation>Oui</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-434"/>
+        <location filename="mainwindow.cpp" line="-446"/>
         <source>Rescan devices and update table</source>
         <translation>Actualiser la liste des médias connectés</translation>
     </message>
@@ -1123,7 +1127,7 @@ Utilise libguytools %5</translation>
         <translation>Ajouter média spécial</translation>
     </message>
     <message>
-        <location line="+155"/>
+        <location line="+161"/>
         <source>Open File</source>
         <translation>Ouvrir fichier</translation>
     </message>
@@ -1182,7 +1186,7 @@ Utilise libguytools %5</translation>
         <translation>non-détectable</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-173"/>
+        <location filename="mainwindow.cpp" line="-179"/>
         <source>Exit after acquisitions completed</source>
         <translation>Terminer Guymager à la fin des acquisitions</translation>
     </message>
@@ -1195,7 +1199,7 @@ Utilise libguytools %5</translation>
         <translation type="obsolete">Abandon - Démarrage échoué</translation>
     </message>
     <message>
-        <location line="+405"/>
+        <location line="+417"/>
         <source>(not used as Guymager currently is configured to use its own EWF module)</source>
         <translation>(inactif, Guymager est configuré d&apos;utiliser son propre module EWF)</translation>
     </message>
