@@ -4,9 +4,9 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="dlgabort.cpp" line="+83"/>
-        <location filename="dlgacquire.cpp" line="+811"/>
-        <location filename="dlgdirsel.cpp" line="+106"/>
+        <location filename="dlgabort.cpp" line="+84"/>
+        <location filename="dlgacquire.cpp" line="+812"/>
+        <location filename="dlgdirsel.cpp" line="+107"/>
         <source>Ok</source>
         <translation type="unfinished"></translation>
     </message>
@@ -19,7 +19,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="file.cpp" line="+67"/>
+        <location filename="file.cpp" line="+68"/>
         <source>Linux dd raw image</source>
         <translation type="unfinished"></translation>
     </message>
@@ -29,7 +29,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="main.cpp" line="+508"/>
+        <location filename="main.cpp" line="+579"/>
         <source>Missing root rights</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -41,7 +41,7 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="threadwrite.cpp" line="+1480"/>
+        <location filename="threadwrite.cpp" line="+1482"/>
         <source>Deleting %1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -51,7 +51,7 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="threadscan.cpp" line="+1440"/>
+        <location filename="threadscan.cpp" line="+1441"/>
         <source>Guymager cannot scan the devices connected to this computer.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -94,7 +94,7 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.h" line="+47"/>
+        <location filename="mainwindow.h" line="+48"/>
         <source>SerialNr</source>
         <translation type="unfinished"></translation>
     </message>
@@ -216,8 +216,8 @@ Continue anyway?</source>
 <context>
     <name>t_DlgAcquire</name>
     <message>
-        <location filename="config.h" line="+274"/>
-        <location filename="table.cpp" line="+345"/>
+        <location filename="config.h" line="+278"/>
+        <location filename="table.cpp" line="+346"/>
         <source>EwfCaseNumber</source>
         <translation type="unfinished"></translation>
     </message>
@@ -594,7 +594,7 @@ Do you want to continue anyway?</source>
 <context>
     <name>t_DlgAutoExit</name>
     <message>
-        <location filename="dlgautoexit.cpp" line="+85"/>
+        <location filename="dlgautoexit.cpp" line="+86"/>
         <source>Abort</source>
         <translation type="unfinished"></translation>
     </message>
@@ -638,7 +638,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_DlgMessage</name>
     <message>
-        <location filename="dlgmessage.cpp" line="+100"/>
+        <location filename="dlgmessage.cpp" line="+101"/>
         <source>Close</source>
         <translation type="unfinished"></translation>
     </message>
@@ -646,13 +646,13 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_Info</name>
     <message>
-        <location filename="info.cpp" line="+201"/>
+        <location filename="info.cpp" line="+202"/>
         <source>Command executed: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location line="+5"/>
-        <source>No information can be displayed as a timeout occured while executing the command.</source>
+        <source>No information can be displayed as a timeout occurred while executing the command.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -664,7 +664,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_InfoField</name>
     <message>
-        <location filename="infofield.cpp" line="+109"/>
+        <location filename="infofield.cpp" line="+110"/>
         <source>Size</source>
         <translation type="unfinished"></translation>
     </message>
@@ -767,7 +767,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_MainWindow</name>
     <message>
-        <location filename="device.cpp" line="+398"/>
+        <location filename="device.cpp" line="+399"/>
         <source>Local device</source>
         <translation type="unfinished"></translation>
     </message>
@@ -792,7 +792,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="+291"/>
+        <location filename="mainwindow.cpp" line="+292"/>
         <source>&amp;Rescan</source>
         <translation type="unfinished"></translation>
     </message>
@@ -837,13 +837,13 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+175"/>
+        <location line="+181"/>
         <source>Device already contained</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+154"/>
+        <location line="+160"/>
         <source>Exit GUYMAGER</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -899,7 +899,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-434"/>
+        <location filename="mainwindow.cpp" line="-446"/>
         <source>Rescan devices and update table</source>
         <translation type="unfinished"></translation>
     </message>
@@ -910,7 +910,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+155"/>
+        <location line="+161"/>
         <source>Open File</source>
         <translation type="unfinished"></translation>
     </message>
@@ -964,12 +964,12 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-173"/>
+        <location filename="mainwindow.cpp" line="-179"/>
         <source>Exit after acquisitions completed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+405"/>
+        <location line="+417"/>
         <source>(not used as Guymager currently is configured to use its own EWF module)</source>
         <translation type="unfinished"></translation>
     </message>
