@@ -4,9 +4,9 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="dlgabort.cpp" line="+83"/>
-        <location filename="dlgacquire.cpp" line="+811"/>
-        <location filename="dlgdirsel.cpp" line="+106"/>
+        <location filename="dlgabort.cpp" line="+84"/>
+        <location filename="dlgacquire.cpp" line="+812"/>
+        <location filename="dlgdirsel.cpp" line="+107"/>
         <source>Ok</source>
         <translation>Ok</translation>
     </message>
@@ -19,7 +19,7 @@
         <translation>Afbreken</translation>
     </message>
     <message>
-        <location filename="file.cpp" line="+67"/>
+        <location filename="file.cpp" line="+68"/>
         <source>Linux dd raw image</source>
         <translation>Linux dd &quot;raw&quot; image</translation>
     </message>
@@ -34,7 +34,7 @@
         <translation>Advanced forensic image</translation>
     </message>
     <message>
-        <location filename="main.cpp" line="+508"/>
+        <location filename="main.cpp" line="+579"/>
         <source>Missing root rights</source>
         <comment>Dialog title</comment>
         <translation>Root rechten benodigd</translation>
@@ -46,12 +46,12 @@ Continue anyway?</source>
         <translation>Guymager moet gestart worden met &quot;root&quot;-rechten om media veilig te kunnen stellen. U bent op dit moment geen &quot;root&quot;, en daarom zult u geen media veilig kunnen stellen.</translation>
     </message>
     <message>
-        <location filename="threadwrite.cpp" line="+1480"/>
+        <location filename="threadwrite.cpp" line="+1482"/>
         <source>Deleting %1</source>
         <translation>%1 aan het verwijderen</translation>
     </message>
     <message>
-        <location filename="threadscan.cpp" line="+1440"/>
+        <location filename="threadscan.cpp" line="+1441"/>
         <source>Guymager cannot scan the devices connected to this computer.</source>
         <translation>Guymager kan geen lijst samenstellen met aangesloten apparaten.</translation>
     </message>
@@ -163,7 +163,7 @@ usage
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.h" line="+47"/>
+        <location filename="mainwindow.h" line="+48"/>
         <source>SerialNr</source>
         <translation type="unfinished"></translation>
     </message>
@@ -285,8 +285,8 @@ usage
 <context>
     <name>t_DlgAcquire</name>
     <message>
-        <location filename="config.h" line="+274"/>
-        <location filename="table.cpp" line="+345"/>
+        <location filename="config.h" line="+278"/>
+        <location filename="table.cpp" line="+346"/>
         <source>EwfCaseNumber</source>
         <translation>Zaaknummer</translation>
     </message>
@@ -687,7 +687,7 @@ Do you want to continue anyway?</source>
 <context>
     <name>t_DlgAutoExit</name>
     <message>
-        <location filename="dlgautoexit.cpp" line="+85"/>
+        <location filename="dlgautoexit.cpp" line="+86"/>
         <source>Abort</source>
         <translation type="unfinished">Afbreken</translation>
     </message>
@@ -731,7 +731,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_DlgMessage</name>
     <message>
-        <location filename="dlgmessage.cpp" line="+100"/>
+        <location filename="dlgmessage.cpp" line="+101"/>
         <source>Close</source>
         <translation>Sluiten</translation>
     </message>
@@ -739,14 +739,18 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_Info</name>
     <message>
-        <location filename="info.cpp" line="+201"/>
+        <location filename="info.cpp" line="+202"/>
         <source>Command executed: %1</source>
         <translation>Uitgevoerd commando: %1</translation>
     </message>
     <message>
         <location line="+5"/>
+        <source>No information can be displayed as a timeout occurred while executing the command.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>No information can be displayed as a timeout occured while executing the command.</source>
-        <translation>De informatie kan niet weergegeven worden tijdens het uitvoeren van het commando.</translation>
+        <translation type="vanished">De informatie kan niet weergegeven worden tijdens het uitvoeren van het commando.</translation>
     </message>
     <message>
         <location line="+7"/>
@@ -757,7 +761,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_InfoField</name>
     <message>
-        <location filename="infofield.cpp" line="+109"/>
+        <location filename="infofield.cpp" line="+110"/>
         <source>Size</source>
         <translation>Grootte</translation>
     </message>
@@ -865,7 +869,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_MainWindow</name>
     <message>
-        <location filename="device.cpp" line="+398"/>
+        <location filename="device.cpp" line="+399"/>
         <source>Local device</source>
         <translation>Lokaal apparaat</translation>
     </message>
@@ -933,7 +937,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="obsolete">Afgebroken - apparaat kan niet gelezen worden</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="+291"/>
+        <location filename="mainwindow.cpp" line="+292"/>
         <source>&amp;Rescan</source>
         <translation>&amp;Herscannen</translation>
     </message>
@@ -978,13 +982,13 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation>Over &amp;Qt&gt;</translation>
     </message>
     <message>
-        <location line="+175"/>
+        <location line="+181"/>
         <source>Device already contained</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+154"/>
+        <location line="+160"/>
         <source>Exit GUYMAGER</source>
         <comment>Dialog title</comment>
         <translation>GUYMAGER Afsluiten</translation>
@@ -1058,7 +1062,7 @@ Using libguytools %5</translation>
         <translation>Ja</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-434"/>
+        <location filename="mainwindow.cpp" line="-446"/>
         <source>Rescan devices and update table</source>
         <translation>Herscan de apparaten en ververs de tabel</translation>
     </message>
@@ -1069,7 +1073,7 @@ Using libguytools %5</translation>
         <translation>Voeg speciaal apparaat toe</translation>
     </message>
     <message>
-        <location line="+155"/>
+        <location line="+161"/>
         <source>Open File</source>
         <translation>Open bestand</translation>
     </message>
@@ -1261,12 +1265,12 @@ Using libguytools %5</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-173"/>
+        <location filename="mainwindow.cpp" line="-179"/>
         <source>Exit after acquisitions completed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+405"/>
+        <location line="+417"/>
         <source>(not used as Guymager currently is configured to use its own EWF module)</source>
         <translation type="unfinished"></translation>
     </message>
