@@ -9,7 +9,8 @@
 //  Module:         Information about the acquisition, creates the info file
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
+// Guy Voncken
 //
 // This file is part of Guymager.
 //
@@ -203,7 +204,7 @@ APIRET t_Info::GetDeviceInfo (t_pcDevice pDevice, bool RichText, QString &Info)
       rc = QtUtilProcessCommand (Command, &Result);
       if (rc == ERROR_QTUTIL_COMMAND_TIMEOUT)
       {
-         Info += "\r\n" + tr("No information can be displayed as a timeout occured while executing the command.");
+         Info += "\r\n" + tr("No information can be displayed as a timeout occurred while executing the command.");
          if (RichText)
             Info += "</b>";
       }
