@@ -11,7 +11,8 @@
 //                  deinitialisation.
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
+// Guy Voncken
 //
 // This file is part of Guymager.
 //
@@ -34,6 +35,7 @@
 #include <locale.h>
 #include <pwd.h>
 #include <unistd.h>
+#include <sys/socket.h>
 
 #include <QApplication>
 #if (QT_VERSION >= 0x050000)
@@ -62,6 +64,7 @@
 #include "dlgmessage.h"
 #include "mainwindow.h"
 #include "main.h"
+#include "main_private.h"
 
 
 // ------------------------------------
@@ -83,7 +86,9 @@ enum
    ERROR_MAIN_UNKNOWN_STARTUP_SIZE = ERROR_BASE_MAIN + 1,
    ERROR_MAIN_INVALID_WINDOW_SIZE,
    ERROR_MAIN_INVALID_NUMBERSTYLE,
-   ERROR_MAIN_LIBEWF_VERSION_MISMATCH
+   ERROR_MAIN_LIBEWF_VERSION_MISMATCH,
+   ERROR_MAIN_SIGACTION_FAILED,
+   ERROR_MAIN_SOCKETPAIR_NOT_CREATED
 };
 
 #define MAIN_SPLASH_PIXMAP             "splash.png"
@@ -107,19 +112,79 @@ enum
 
 typedef struct                // Objects that exist only once for the whole application
 {
-   QApplication  *pApp;
-   QLocale       *pNumberLocale; // The QLocale for number conversions
-   t_Log         *pLog;
-   t_MainWindow  *pMainWindow;
-   t_pDeviceList  pDeviceList;
-   bool            CriticalInitDone;
-   char          *pCommandLine;
+   QApplication                *pApp;
+   QLocale                     *pNumberLocale; // The QLocale for number conversions
+   t_Log                       *pLog;
+   t_MainWindow                *pMainWindow;
+   t_pDeviceList                pDeviceList;
+   bool                          CriticalInitDone;
+   char                        *pCommandLine;
+   t_MainSystemSignalForwarder *pSystemSignalForwarder;
 } t_MainLocal;
 
 static t_MainLocal MainLocal;
 
 // ------------------------------------
-//       Signal & error handling
+//       System signal forwarding
+// ------------------------------------
+
+// See http://doc.qt.io/qt-5/unix-signals.html for explanantions
+// Code of t_MainSystemSignalForwarder mainly has been copied from that web page
+
+int t_MainSystemSignalForwarder::oArrFileDescHup[2];
+
+t_MainSystemSignalForwarder::t_MainSystemSignalForwarder (QObject *parent)
+   :QObject(parent)
+{
+   struct sigaction SigActionHup;
+	
+   if (::socketpair(AF_UNIX, SOCK_STREAM, 0, oArrFileDescHup))
+      CHK_EXIT (ERROR_MAIN_SOCKETPAIR_NOT_CREATED)
+
+   poSocketNotifierHup = new QSocketNotifier (oArrFileDescHup[1], QSocketNotifier::Read, this);
+   connect (poSocketNotifierHup, SIGNAL(activated(int)), this, SLOT(SlotHup()));
+   
+   sigemptyset (&SigActionHup.sa_mask);
+   SigActionHup.sa_handler = SignalHandlerHup;
+   SigActionHup.sa_flags   = 0;
+   SigActionHup.sa_flags  |= SA_RESTART;
+   if (sigaction(SIGHUP, &SigActionHup, 0))
+      CHK_EXIT (ERROR_MAIN_SIGACTION_FAILED)
+}      
+      
+t_MainSystemSignalForwarder::~t_MainSystemSignalForwarder ()
+{
+}
+
+void t_MainSystemSignalForwarder::SignalHandlerHup (int Signal) // Unix signal handler
+{
+   if (Signal != SIGHUP)
+   {
+      LOG_ERROR ("Unexpected signal %d", Signal)
+      return;
+   }
+   
+   char Ch = '1';
+   if (::write (oArrFileDescHup[0], &Ch, sizeof(Ch)) != 1)
+      LOG_ERROR ("Write to socket failed")
+}
+    
+void t_MainSystemSignalForwarder::SlotHup()
+{
+   char Ch;
+
+   poSocketNotifierHup->setEnabled(false);
+   if (::read(oArrFileDescHup[1], &Ch, sizeof(Ch)) != 1)
+      LOG_ERROR ("Read from socket failed")
+
+//   LOG_INFO ("Signal HUP received (rescan)")
+   MainLocal.pMainWindow->SlotRescan();
+
+   poSocketNotifierHup->setEnabled(true);
+}
+      
+// ------------------------------------
+//          Error handling
 // ------------------------------------
 
 #if (QT_VERSION >= 0x050000)
@@ -261,13 +326,13 @@ class t_MainTranslator : public QTranslator    // Has been extended initially to
          (void) oDict.insert (Source, Translation);
       }
 
-      QString translate (const char *pContext, const char *pSourceText, const char *pDisambiguation = 0) const
+      QString translate (const char *pContext, const char *pSourceText, const char *pDisambiguation = 0, int n = -1) const
       {
          QString Source(pSourceText);
 
          if (oDict.contains (Source))
               return oDict.value (Source);
-         else return QTranslator::translate (pContext, pSourceText, pDisambiguation);
+         else return QTranslator::translate (pContext, pSourceText, pDisambiguation, n);
       }
 
       bool isEmpty (void) const
@@ -279,6 +344,7 @@ class t_MainTranslator : public QTranslator    // Has been extended initially to
       QHash<QString, QString> oDict;
 };
 
+
 // ------------------------------------
 //           Main program
 // ------------------------------------
@@ -333,6 +399,8 @@ static APIRET MainGo (int argc, char *argv[], bool *pAutoExit)
    CHK_EXIT (TOOL_ERROR_REGISTER_CODE   (ERROR_MAIN_INVALID_WINDOW_SIZE    ))
    CHK_EXIT (TOOL_ERROR_REGISTER_CODE   (ERROR_MAIN_INVALID_NUMBERSTYLE    ))
    CHK_EXIT (TOOL_ERROR_REGISTER_CODE   (ERROR_MAIN_LIBEWF_VERSION_MISMATCH))
+   CHK_EXIT (TOOL_ERROR_REGISTER_CODE   (ERROR_MAIN_SIGACTION_FAILED       ))
+   CHK_EXIT (TOOL_ERROR_REGISTER_CODE   (ERROR_MAIN_SOCKETPAIR_NOT_CREATED ))
 
    CHK_EXIT (ToolErrorSetLogFn          (&t_Log::vEntryError))
    CHK_EXIT (ToolCfgInit                (argc, argv))
@@ -438,7 +506,6 @@ static APIRET MainGo (int argc, char *argv[], bool *pAutoExit)
    if (!LangDirQt.endsWith ("/")) LangDirQt += "/";
    if (!LangDir  .endsWith ("/")) LangDir   += "/";
 
-
    // Select correct Qt language file. We only try once. If this does not
    // succeed, Qt automatically uses its english language file.
 
@@ -485,9 +552,13 @@ static APIRET MainGo (int argc, char *argv[], bool *pAutoExit)
    {
       LOG_INFO ("Language file %s not found in %s. Not using any language file.", QSTR_TO_PSZ(TryName), QSTR_TO_PSZ(TryDir))
    }
+
    if (strlen (CONFIG(UserFieldName)))
-      TranslatorDynamic.Insert (MAINWINDOW_COLUMN_UserField, CONFIG(UserFieldName));
-   MainLocal.pApp->installTranslator (&TranslatorDynamic);
+      TranslatorDynamic.Insert (MAINWINDOW_COLUMN_UserField   , CONFIG(UserFieldName));
+   if (strlen (CONFIG(AdditionalStateInfoName)))
+      TranslatorDynamic.Insert (MAINWINDOW_COLUMN_AddStateInfo, CONFIG(AdditionalStateInfoName));
+   MainLocal.pApp->installTranslator (&TranslatorDynamic);  // TranslatorDynamic is installed last, so it will be queried first
+                                                            // and its translation will beat all others if ever it has a hit.
 
    // Check real and effective user ID
    // --------------------------------
@@ -525,8 +596,11 @@ static APIRET MainGo (int argc, char *argv[], bool *pAutoExit)
       }
    }
 
-   // Initialise signal handler
-   // -------------------------
+   // Install system signal handlers
+   // ------------------------------
+
+   MainLocal.pSystemSignalForwarder = new t_MainSystemSignalForwarder();
+
    if (CONFIG (SignalHandling))
       CHK_EXIT (ToolSignalInit (MainSignalLog, MainSignalHandler, NULL))
 
