@@ -10,7 +10,8 @@
 //                  widget
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
+// Guy Voncken
 //
 // This file is part of Guymager.
 //
@@ -67,27 +68,27 @@ const int MAINWINDOW_WAIT_FOR_THREADS_TO_ABORT = 5000;
 
 static t_MainWindowColumn MainWindowColumnArr[] =
 {
-   { MAINWINDOW_COLUMN_SerialNr           , t_Device::GetSerialNumber  , t_ItemDelegate::DISPLAYTYPE_STANDARD },
-   { MAINWINDOW_COLUMN_LinuxDevice        , t_Device::GetLinuxDevice   , t_ItemDelegate::DISPLAYTYPE_STANDARD },
-   { MAINWINDOW_COLUMN_Model              , t_Device::GetModel         , t_ItemDelegate::DISPLAYTYPE_STANDARD },
-   { MAINWINDOW_COLUMN_NativePath         , t_Device::GetNativePath    , t_ItemDelegate::DISPLAYTYPE_STANDARD },
-   { MAINWINDOW_COLUMN_ByPath             , t_Device::GetByPath        , t_ItemDelegate::DISPLAYTYPE_STANDARD },
-   { MAINWINDOW_COLUMN_Interface          , t_Device::GetInterface     , t_ItemDelegate::DISPLAYTYPE_STANDARD },
-   { MAINWINDOW_COLUMN_State              , t_Device::GetState         , t_ItemDelegate::DISPLAYTYPE_STATE    },
-   { MAINWINDOW_COLUMN_AdditionalStateInfo, t_Device::GetAddStateInfo  , t_ItemDelegate::DISPLAYTYPE_STANDARD },
-   { MAINWINDOW_COLUMN_Size               , t_Device::GetSizeHuman     , t_ItemDelegate::DISPLAYTYPE_STANDARD },
-   { MAINWINDOW_COLUMN_HiddenAreas        , t_Device::GetHiddenAreas   , t_ItemDelegate::DISPLAYTYPE_STANDARD },
-   { MAINWINDOW_COLUMN_BadSectors         , t_Device::GetBadSectorCount, t_ItemDelegate::DISPLAYTYPE_STANDARD },
-   { MAINWINDOW_COLUMN_Progress           , t_Device::GetProgress      , t_ItemDelegate::DISPLAYTYPE_PROGRESS },
-   { MAINWINDOW_COLUMN_AverageSpeed       , t_Device::GetAverageSpeed  , t_ItemDelegate::DISPLAYTYPE_STANDARD },
-   { MAINWINDOW_COLUMN_TimeRemaining      , t_Device::GetRemaining     , t_ItemDelegate::DISPLAYTYPE_STANDARD },
-   { MAINWINDOW_COLUMN_FifoUsage          , t_Device::GetFifoStatus    , t_ItemDelegate::DISPLAYTYPE_STANDARD },
-   { MAINWINDOW_COLUMN_SectorSizeLog      , t_Device::GetSectorSize    , t_ItemDelegate::DISPLAYTYPE_STANDARD },
-   { MAINWINDOW_COLUMN_SectorSizePhys     , t_Device::GetSectorSizePhys, t_ItemDelegate::DISPLAYTYPE_STANDARD },
-   { MAINWINDOW_COLUMN_CurrentSpeed       , t_Device::GetCurrentSpeed  , t_ItemDelegate::DISPLAYTYPE_STANDARD },
-   { MAINWINDOW_COLUMN_UserField          , t_Device::GetUserField     , t_ItemDelegate::DISPLAYTYPE_STANDARD },
-   { MAINWINDOW_COLUMN_Examiner           , t_Device::GetExaminer      , t_ItemDelegate::DISPLAYTYPE_STANDARD },
-   { NULL                                 , NULL                       , 0                                    }
+   { MAINWINDOW_COLUMN_SerialNr      , t_Device::GetSerialNumber  , t_ItemDelegate::DISPLAYTYPE_STANDARD },
+   { MAINWINDOW_COLUMN_LinuxDevice   , t_Device::GetLinuxDevice   , t_ItemDelegate::DISPLAYTYPE_STANDARD },
+   { MAINWINDOW_COLUMN_Model         , t_Device::GetModel         , t_ItemDelegate::DISPLAYTYPE_STANDARD },
+   { MAINWINDOW_COLUMN_NativePath    , t_Device::GetNativePath    , t_ItemDelegate::DISPLAYTYPE_STANDARD },
+   { MAINWINDOW_COLUMN_ByPath        , t_Device::GetByPath        , t_ItemDelegate::DISPLAYTYPE_STANDARD },
+   { MAINWINDOW_COLUMN_Interface     , t_Device::GetInterface     , t_ItemDelegate::DISPLAYTYPE_STANDARD },
+   { MAINWINDOW_COLUMN_State         , t_Device::GetState         , t_ItemDelegate::DISPLAYTYPE_STATE    },
+   { MAINWINDOW_COLUMN_AddStateInfo  , t_Device::GetAddStateInfo  , t_ItemDelegate::DISPLAYTYPE_STANDARD },
+   { MAINWINDOW_COLUMN_Size          , t_Device::GetSizeHuman     , t_ItemDelegate::DISPLAYTYPE_STANDARD },
+   { MAINWINDOW_COLUMN_HiddenAreas   , t_Device::GetHiddenAreas   , t_ItemDelegate::DISPLAYTYPE_STANDARD },
+   { MAINWINDOW_COLUMN_BadSectors    , t_Device::GetBadSectorCount, t_ItemDelegate::DISPLAYTYPE_STANDARD },
+   { MAINWINDOW_COLUMN_Progress      , t_Device::GetProgress      , t_ItemDelegate::DISPLAYTYPE_PROGRESS },
+   { MAINWINDOW_COLUMN_AverageSpeed  , t_Device::GetAverageSpeed  , t_ItemDelegate::DISPLAYTYPE_STANDARD },
+   { MAINWINDOW_COLUMN_TimeRemaining , t_Device::GetRemaining     , t_ItemDelegate::DISPLAYTYPE_STANDARD },
+   { MAINWINDOW_COLUMN_FifoUsage     , t_Device::GetFifoStatus    , t_ItemDelegate::DISPLAYTYPE_STANDARD },
+   { MAINWINDOW_COLUMN_SectorSizeLog , t_Device::GetSectorSize    , t_ItemDelegate::DISPLAYTYPE_STANDARD },
+   { MAINWINDOW_COLUMN_SectorSizePhys, t_Device::GetSectorSizePhys, t_ItemDelegate::DISPLAYTYPE_STANDARD },
+   { MAINWINDOW_COLUMN_CurrentSpeed  , t_Device::GetCurrentSpeed  , t_ItemDelegate::DISPLAYTYPE_STANDARD },
+   { MAINWINDOW_COLUMN_UserField     , t_Device::GetUserField     , t_ItemDelegate::DISPLAYTYPE_STANDARD },
+   { MAINWINDOW_COLUMN_Examiner      , t_Device::GetExaminer      , t_ItemDelegate::DISPLAYTYPE_STANDARD },
+   { NULL                            , NULL                       , 0                                    }
 };
 
 t_pMainWindowColumn MainWindowGetColumn (const char *pName)
@@ -434,6 +435,12 @@ void t_MainWindow::SlotRefresh (void)
    CHK_EXIT (CheckDisconnectTimeout())
 }
 
+void t_MainWindow::SlotRescan (void)
+{
+   if (pOwn->pActionRescan->isEnabled())
+      pOwn->pActionRescan->trigger();
+}
+
 void t_MainWindow::SlotUpdateRunStats (void)
 {
    pOwn->pRunStats->Update ();
@@ -522,9 +529,11 @@ void t_MainWindow::SlotScanStarted (void)
 //        Set the state of the device in the current list to Connected. Thus, devices that were temporarly disconnected
 //        will become connected again.
 //  (2) For devices, that only exist in the current list (but no longer in the new list):
-//        a) delete from the current list if there was no acquisition running
-//        b) switch to disconnected if there was an acquisition running, thus giving the user a chance to continue to acquistion
-//           on another device (for instance, if the hard disk had been unpligged from firewrie and plugged to USB)
+//        a) delete from the current list if there was no acquisition or verifictaion running
+//        b) switch to disconnected if there was an acquisition or source verification running, thus giving the user a 
+//           chance to continue that acquisition on another device (for instance, if the hard disk had been unplugged from firewire 
+//           and replugged to USB)
+//        c) Do nothing if there's a verification running where only the image is verified
 //  (3) For devices, that only exist in the new list:
 //        Add to the current list
 // Remark: Is it quite tricky to compare the devices from both lists, as there devices without a serial number. See
@@ -588,7 +597,7 @@ void t_MainWindow::SlotScanFinished (t_pDeviceList pNewDeviceList)
       {
          pNewDev->Checked  = true;
          pNewDev->AddedNow = true;
-         pNewDeviceList->removeAt (i--);                 // (3)
+         pNewDeviceList->removeAt (i--);                      // (3)
          pDeviceList->append (pNewDev);
       }
    }
@@ -600,11 +609,15 @@ void t_MainWindow::SlotScanFinished (t_pDeviceList pNewDeviceList)
       {
          switch (pDev->GetState())
          {
-            case t_Device::Acquire      : pDev->SetState (t_Device::AcquirePaused); break;  // (2b)
-            case t_Device::Verify       : pDev->SetState (t_Device::VerifyPaused ); break;  // (2b)
+            case t_Device::Acquire      : pDev->SetState (t_Device::AcquirePaused);            // (2b)
+                                          break;
+            case t_Device::Verify       : if (pDev->Acquisition1.VerifySrc)
+                                             pDev->SetState (t_Device::VerifyPaused );         // (2b)
+                                          // else do nothing                                   // (2c)
+                                          break;
             case t_Device::AcquirePaused: break;
             case t_Device::VerifyPaused : break;
-            default                     : pDeviceList->removeAt (i--);                     // (2a)
+            default                     : pDeviceList->removeAt (i--);                         // (2a)
                                           delete pDev;
          }
       }
