@@ -7,7 +7,8 @@
 //                  Section Nouvelles Technologies
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
+// Guy Voncken
 //
 // This file is part of Guymager.
 //
@@ -44,26 +45,26 @@
 // Main window table column names
 // ------------------------------
 
-#define MAINWINDOW_COLUMN_SerialNr             QT_TRANSLATE_NOOP("t_DeviceListModel", "SerialNr"           )
-#define MAINWINDOW_COLUMN_LinuxDevice          QT_TRANSLATE_NOOP("t_DeviceListModel", "LinuxDevice"        )
-#define MAINWINDOW_COLUMN_Model                QT_TRANSLATE_NOOP("t_DeviceListModel", "Model"              )
-#define MAINWINDOW_COLUMN_NativePath           QT_TRANSLATE_NOOP("t_DeviceListModel", "NativePath"         )
-#define MAINWINDOW_COLUMN_ByPath               QT_TRANSLATE_NOOP("t_DeviceListModel", "ByPath"             )
-#define MAINWINDOW_COLUMN_Interface            QT_TRANSLATE_NOOP("t_DeviceListModel", "Interface"          )
-#define MAINWINDOW_COLUMN_State                QT_TRANSLATE_NOOP("t_DeviceListModel", "State"              )
-#define MAINWINDOW_COLUMN_AdditionalStateInfo  QT_TRANSLATE_NOOP("t_DeviceListModel", "AdditionalStateInfo")
-#define MAINWINDOW_COLUMN_Size                 QT_TRANSLATE_NOOP("t_DeviceListModel", "Size"               )
-#define MAINWINDOW_COLUMN_HiddenAreas          QT_TRANSLATE_NOOP("t_DeviceListModel", "HiddenAreas"        )
-#define MAINWINDOW_COLUMN_BadSectors           QT_TRANSLATE_NOOP("t_DeviceListModel", "BadSectors"         )
-#define MAINWINDOW_COLUMN_Progress             QT_TRANSLATE_NOOP("t_DeviceListModel", "Progress"           )
-#define MAINWINDOW_COLUMN_AverageSpeed         QT_TRANSLATE_NOOP("t_DeviceListModel", "AverageSpeed"       )
-#define MAINWINDOW_COLUMN_TimeRemaining        QT_TRANSLATE_NOOP("t_DeviceListModel", "TimeRemaining"      )
-#define MAINWINDOW_COLUMN_FifoUsage            QT_TRANSLATE_NOOP("t_DeviceListModel", "FifoUsage"          )
-#define MAINWINDOW_COLUMN_SectorSizeLog        QT_TRANSLATE_NOOP("t_DeviceListModel", "SectorSizeLog"      )
-#define MAINWINDOW_COLUMN_SectorSizePhys       QT_TRANSLATE_NOOP("t_DeviceListModel", "SectorSizePhys"     )
-#define MAINWINDOW_COLUMN_CurrentSpeed         QT_TRANSLATE_NOOP("t_DeviceListModel", "CurrentSpeed"       )
-#define MAINWINDOW_COLUMN_UserField                                                   "UserField" // No automatic Qt translation for this one, see t_MainTranslator
-#define MAINWINDOW_COLUMN_Examiner             QT_TRANSLATE_NOOP("t_DeviceListModel", "Examiner"           )
+#define MAINWINDOW_COLUMN_SerialNr       QT_TRANSLATE_NOOP("t_DeviceListModel", "SerialNr"           )
+#define MAINWINDOW_COLUMN_LinuxDevice    QT_TRANSLATE_NOOP("t_DeviceListModel", "LinuxDevice"        )
+#define MAINWINDOW_COLUMN_Model          QT_TRANSLATE_NOOP("t_DeviceListModel", "Model"              )
+#define MAINWINDOW_COLUMN_NativePath     QT_TRANSLATE_NOOP("t_DeviceListModel", "NativePath"         )
+#define MAINWINDOW_COLUMN_ByPath         QT_TRANSLATE_NOOP("t_DeviceListModel", "ByPath"             )
+#define MAINWINDOW_COLUMN_Interface      QT_TRANSLATE_NOOP("t_DeviceListModel", "Interface"          )
+#define MAINWINDOW_COLUMN_State          QT_TRANSLATE_NOOP("t_DeviceListModel", "State"              )
+#define MAINWINDOW_COLUMN_AddStateInfo   QT_TRANSLATE_NOOP("t_DeviceListModel", "AdditionalStateInfo")
+#define MAINWINDOW_COLUMN_Size           QT_TRANSLATE_NOOP("t_DeviceListModel", "Size"               )
+#define MAINWINDOW_COLUMN_HiddenAreas    QT_TRANSLATE_NOOP("t_DeviceListModel", "HiddenAreas"        )
+#define MAINWINDOW_COLUMN_BadSectors     QT_TRANSLATE_NOOP("t_DeviceListModel", "BadSectors"         )
+#define MAINWINDOW_COLUMN_Progress       QT_TRANSLATE_NOOP("t_DeviceListModel", "Progress"           )
+#define MAINWINDOW_COLUMN_AverageSpeed   QT_TRANSLATE_NOOP("t_DeviceListModel", "AverageSpeed"       )
+#define MAINWINDOW_COLUMN_TimeRemaining  QT_TRANSLATE_NOOP("t_DeviceListModel", "TimeRemaining"      )
+#define MAINWINDOW_COLUMN_FifoUsage      QT_TRANSLATE_NOOP("t_DeviceListModel", "FifoUsage"          )
+#define MAINWINDOW_COLUMN_SectorSizeLog  QT_TRANSLATE_NOOP("t_DeviceListModel", "SectorSizeLog"      )
+#define MAINWINDOW_COLUMN_SectorSizePhys QT_TRANSLATE_NOOP("t_DeviceListModel", "SectorSizePhys"     )
+#define MAINWINDOW_COLUMN_CurrentSpeed   QT_TRANSLATE_NOOP("t_DeviceListModel", "CurrentSpeed"       )
+#define MAINWINDOW_COLUMN_UserField                                             "UserField" // No automatic Qt translation for this one, see t_MainTranslator
+#define MAINWINDOW_COLUMN_Examiner       QT_TRANSLATE_NOOP("t_DeviceListModel", "Examiner"           )
 
 // Main window classes
 // -------------------
@@ -89,6 +90,9 @@ class t_MainWindow: public QMainWindow
    protected:
       void closeEvent (QCloseEvent *pEvent);
 
+   public slots:
+      void SlotRescan           (void);
+      
    private slots:
       void SlotAddSpecialDevice (void);
       void SlotDebug            (void);
