@@ -9,7 +9,8 @@
 //  Module:         Thread for reading data.
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
+// Guy Voncken
 //
 // This file is part of Guymager.
 //
@@ -212,6 +213,7 @@ APIRET t_ThreadRead::ThreadReadBlock (t_pFifoBlock &pFifoBlock)
    quint64         BytesRead = 0;
    quint64         RemainingSize;
    quint64         Sector;
+   quint64         BadSectorCount;
    quint64         PrevReadPos;
    unsigned int    ReadTry;
    APIRET          RcRead;
@@ -270,8 +272,15 @@ APIRET t_ThreadRead::ThreadReadBlock (t_pFifoBlock &pFifoBlock)
                      else memset (pBuffer, 0, ReadTry);
                      BytesRead += ReadTry;
                      pBuffer   += ReadTry;
-                     LOG_INFO ("[%s] Read error on sector %Ld, bad data replaced by zero block", QSTR_TO_PSZ(pDevice->LinuxDevice), Sector)
+
                      pDevice->AddBadSector (Sector);
+                     BadSectorCount = pDevice->GetBadSectorCount (false);
+                     if ( CONFIG(BadSectorLogThreshold) == 0                          ||  // Threshold feature disabled if cfg param is zero
+                          (BadSectorCount <= (quint64) CONFIG(BadSectorLogThreshold)) ||
+                         ((BadSectorCount %  (quint64) CONFIG(BadSectorLogModulo   )) == 0))
+                        LOG_INFO ("[%s] Read error on sector %Ld, bad data replaced by zero block (%Ld bad sectors up until now)", QSTR_TO_PSZ(pDevice->LinuxDevice), Sector, BadSectorCount)
+                     if (BadSectorCount == (quint64)CONFIG(BadSectorLogThreshold))
+                        LOG_INFO ("[%s] Bad sector threshold has been reached, only logging every 1000th bad sector from now on.", QSTR_TO_PSZ(pDevice->LinuxDevice), Sector)
 
                      if (CONFIG(JobMaxBadSectors) &&
                         (CONFIG(LimitJobs) != CONFIG_LIMITJOBS_OFF) &&
