@@ -9,7 +9,8 @@
 //  Module:         Thread for writing data.
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
+// Guy Voncken
 //
 // This file is part of Guymager.
 //
@@ -1483,7 +1484,7 @@ static APIRET DeleteImageFiles0 (t_pDevice pDevice, const QDir &Dir, const QStri
       Info = "Deleting " + FileInfo.absoluteFilePath() + " - ";
       Success = QFile::remove (FileInfo.absoluteFilePath());
       if (Success)
-           Info += "successfull";
+           Info += "successful";
       else Info += "could not be deleted";
       LOG_INFO ("[%s] %s", QSTR_TO_PSZ (pDevice->LinuxDevice), QSTR_TO_PSZ(Info))
    }
